@@ -23,21 +23,34 @@ import GLib from 'gi://GLib';
 import Soup from 'gi://Soup';
 
 import {Application} from './application.js';
+import {KEY} from './graphHopper.js';
 import * as HTTP from './http.js';
 import * as PhotonUtils from './photonUtils.js';
-import * as Service from './service.js';
 import * as Utils from './utils.js';
 
 // HTTP session timeout (in seconds)
 const TIMEOUT = 5;
 
+const BASE_URL = 'https://graphhopper.com';
+const ATTRIBUTION = 'GraphHopper';
+const ATTRIBUTION_URL = 'https://graphhopper.com/';
+const SUPPORTED_LANGUAGES = ['de', 'en', 'fr'];
+
 export class GraphHopperGeocode {
     constructor() {
         this._session =
             new Soup.Session({ user_agent : 'gnome-maps/' + pkg.version,
                                timeout:     TIMEOUT });
-        this._readService();
         this._limit = Application.settings.get('max-search-results');
+
+        const language = Utils.getLanguage();
+
+        /* for now fallback to English as language when not using a language
+         * supported by GraphHopper, as leaving out language to fallback to
+         * default is currently not working as expected:
+         * https://github.com/komoot/photon/issues/746
+         */
+        this._language = SUPPORTED_LANGUAGES.includes(language) ? language : 'en';
     }
 
     search(string, latitude, longitude, cancellable, callback) {
@@ -70,35 +83,12 @@ export class GraphHopperGeocode {
         });
     }
 
-    reverse(latitude, longitude, callback) {
-        let url = this._buildURL(null, latitude, longitude);
-        let msg = Soup.Message.new('GET', url);
-
-        Application.application.mark_busy();
-        this._session.send_and_read_async(msg, GLib.PRIORITY_DEFAULT, null,
-                                          (source, res) => {
-            Application.application.unmark_busy();
-            try {
-                let buffer = this._session.send_and_read_finish(res).get_data();
-
-                let result = this._parseMessage(Utils.getBufferText(buffer));
-                if (!result)
-                    callback(null, null);
-                else
-                    callback(result[0], null);
-            } catch (e) {
-                Utils.debug('Error: ' + e);
-                callback(null, e);
-            }
-        });
-    }
-
     get attribution() {
-        return Service.getService().graphHopperGeocode.attribution;
+        return ATTRIBUTION;
     }
 
     get attributionUrl() {
-        return Service.getService().graphHopperGeocode.attributionUrl;
+        return ATTRIBUTION_URL;
     }
 
     get name() {
@@ -137,39 +127,15 @@ export class GraphHopperGeocode {
     }
 
     _buildURL(string, latitude, longitude) {
-        let query = new HTTP.Query({ limit:   string ? this._limit : 1,
+        let query = new HTTP.Query({ limit:   this._limit,
                                      locale:  this._language,
-                                     key:     this._apiKey
+                                     q:       string,
+                                     location_bias_scale: PhotonUtils.LOCATION_BIAS_SCALE,
+                                     key:     KEY
                                    });
-        if (latitude !== null && longitude != null) {
+        if (latitude !== null && longitude != null)
             query.add('point', latitude + ',' + longitude);
-            if (string)
-                query.add('location_bias_scale', PhotonUtils.LOCATION_BIAS_SCALE);
-        }
 
-        if (string)
-            query.add('q', string);
-        else
-            query.add('reverse', 'true');
-
-        return `${this._baseUrl}/api/1/geocode?${query.toString()}`;
-    }
-
-    _readService() {
-        let graphHopperGeocode = Service.getService().graphHopperGeocode;
-
-        if (graphHopperGeocode) {
-            this._baseUrl = graphHopperGeocode.baseUrl;
-            this._apiKey = graphHopperGeocode.apiKey;
-
-            let language = Utils.getLanguage();
-            let supportedLanguages =
-                graphHopperGeocode.supportedLanguages ?? [];
-
-            if (supportedLanguages.includes(language))
-                this._language = language;
-            else
-                this._language = null;
-        }
+        return `${BASE_URL}/api/1/geocode?${query.toString()}`;
     }
 }
