@@ -258,14 +258,20 @@ export class MapView extends Gtk.Overlay {
                                           margin_top:    6,
                                           margin_bottom: 6 });
 
-        if (Utils.getMeasurementSystem() === Utils.METRIC_SYSTEM)
-            this._scale.unit = Shumate.Unit.METRIC;
-        else
-            this._scale.unit = Shumate.Unit.IMPERIAL;
+        this._setScaleUnit();
+
+        Application.settings.connect('changed::measurement-system', () => {
+            this._setScaleUnit();
+        });
 
         this.add_overlay(this._scale);
     }
 
+    _setScaleUnit() {
+        this._scale.unit = Utils.shouldShowImperialUnits() ?
+                           Shumate.Unit.IMPERIAL : Shumate.Unit.METRIC;
+    }
+
     _initMap() {
         let map = new Shumate.Map();
 
@@ -520,7 +526,7 @@ export class MapView extends Gtk.Overlay {
         const className = symbol.get_tag("class");
 
         const featureType = featureId % 10;
-        const osmId = Math.floor(featureId / 10);
+        let osmId = Math.floor(featureId / 10);
 
         let osmType;
         if (featureType === 0) {
@@ -533,6 +539,9 @@ export class MapView extends Gtk.Overlay {
             osmType = GeocodeGlib.PlaceOsmType.UNKNOWN;
         }
 
+        let latitude = symbol.latitude;
+        let longitude = symbol.longitude;
+
         switch (layerName) {
             case "place":
                 placeType = {
@@ -558,6 +567,12 @@ export class MapView extends Gtk.Overlay {
                     "ocean": GeocodeGlib.PlaceType.OCEAN,
                     "sea": GeocodeGlib.PlaceType.SEA,
                 }[className] ?? GeocodeGlib.PlaceType.DRAINAGE;
+
+                // adjust coordinates to the actual click target
+                [latitude, longitude] =
+                    this.map.viewport.widget_coords_to_location(this,
+                                                                this._pressX,
+                                                                this._pressY);
                 break;
 
             case "poi":
@@ -576,14 +591,49 @@ export class MapView extends Gtk.Overlay {
                 placeType =  GeocodeGlib.PlaceType.POINT_OF_INTEREST;
                 break;
 
+            case "transportation_name":
+                placeType = {
+                    "motorway": GeocodeGlib.PlaceType.MOTORWAY
+                }[className] ?? GeocodeGlib.PlaceType.STREET;
+
+                // adjust coordinates to the actual click target
+                [latitude, longitude] =
+                    this.map.viewport.widget_coords_to_location(this,
+                                                                this._pressX,
+                                                                this._pressY);
+
+                break;
+
+            case "waterway":
+                placeType = GeocodeGlib.PlaceType.DRAINAGE;
+
+                // adjust coordinates to the actual click target
+                [latitude, longitude] =
+                    this.map.viewport.widget_coords_to_location(this,
+                                                                this._pressX,
+                                                                this._pressY);
+
+                /* for waterways, the OSM type will always be "way",
+                 * the feature ID is the same as the OSM way ID.
+                 */
+                osmType = GeocodeGlib.PlaceOsmType.WAY;
+                osmId = featureId;
+
+                break;
+
+            case "housenumber":
+                placeType = GeocodeGlib.PlaceType.UNKNOWN;
+
+                break;
+
             default:
                 return;
         }
 
         const place = new Place({
             location: new Location({
-                latitude: symbol.latitude,
-                longitude: symbol.longitude
+                latitude:  latitude,
+                longitude: longitude
             }),
             placeType,
             name: symbol.get_tag("name"),
@@ -595,7 +645,8 @@ export class MapView extends Gtk.Overlay {
         for (const key of symbol.get_keys()) {
             if (key.startsWith("osm:")) {
                 osmTags[key.slice("osm:".length)] = symbol.get_tag(key);
-            } else if (key === "name" || key.startsWith("name:")) {
+            } else if (key === "name" || key.startsWith("name:") ||
+                       key.startsWith("route_")) {
                 osmTags[key] = symbol.get_tag(key);
             }
         }
@@ -1155,6 +1206,8 @@ export class MapView extends Gtk.Overlay {
 
         this._pressLatitude = this.map.viewport.latitude;
         this._pressLongitude = this.map.viewport.longitude;
+        this._pressX = x;
+        this._pressY = y;
 
         // remove any showing place markers when clicking outside
         this._placeLayer.remove_all();
