@@ -87,7 +87,7 @@ export class Overpass {
                 let element = jsonObj?.elements?.[0];
 
                 if (element) {
-                    place.osmTags = element.tags;
+                    place.osmTags = {...place.osmTags, ...element.tags};
                     callback(true);
                 } else {
                     Utils.debug('No element in Overpass result');
@@ -316,15 +316,12 @@ export class Overpass {
         let data = '(';
 
         for (let disjunction of category.keyValues) {
-            for (let type of ['node', 'way', 'relation']) {
-                data += `${type}(around:${radius},${lat},${lon})`;
-
-                for (let kv of disjunction) {
-                    data += `[${kv}]`;
-                }
-
-                data += ';';
+            data += `nwr(around:${radius},${lat},${lon})`;
+            for (const kv of disjunction) {
+                data += `[${kv}]`;
             }
+
+            data += ';';
         }
 
         data += ')';
