@@ -20,6 +20,7 @@
  */
 
 
+import GeocodeGlib from 'gi://GeocodeGlib';
 import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
 
@@ -28,6 +29,7 @@ import {OSMAccountDialog} from './osmAccountDialog.js';
 import {OSMEditDialog} from './osmEditDialog.js';
 import {PlaceStore} from './placeStore.js';
 import {SendToDialog} from './sendToDialog.js';
+import * as Utils from './utils.js';
 
 export class PlaceButtons extends Gtk.Box {
     constructor({place, mapView, ...params}) {
@@ -54,7 +56,11 @@ export class PlaceButtons extends Gtk.Box {
 
         this._updateFavoriteButton(!!this._place.store);
 
-        this._editButton.visible = !!this._place.osmId;
+        this._editButton.visible =
+            !!this._place.osmId && this._place.osmType !== GeocodeGlib.PlaceOsmType.UNKNOWN;
+
+        if (Utils.isLefthandTrafficForCountry(this._place.countryCode))
+            this._routeButton.child.icon_name = 'route-button-lht-symbolic';
 
         this._routeButton.visible = !this._place.isCurrentLocation;
     }
