@@ -23,6 +23,7 @@ import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
 
+import * as Gfx from './gfx.js';
 import {PlaceFormatter} from './placeFormatter.js';
 import * as Utils from './utils.js';
 import { Application } from './application.js';
@@ -74,7 +75,12 @@ export class PlaceListRow extends Gtk.ListBoxRow {
         this._details.label = GLib.markup_escape_text(formatter.getDetailsString(),-1);
         this._details.visible = this._details.label.length > 0;
 
-        if (place.icon)
+        const shieldPaintables =
+            Gfx.drawShieldsForPlace(place, 1, this.get_scale_factor());
+
+        if (shieldPaintables.length > 0)
+            this._icon.paintable = shieldPaintables[0];
+        else if (place.icon)
             this._icon.gicon = place.icon;
 
         const placeItem = Application.placeStore.getPlaceItem(place);
@@ -98,22 +104,22 @@ export class PlaceListRow extends Gtk.ListBoxRow {
         let distance = this.place.location.get_distance_from(location) * 1000;
         let label;
 
-        if (Utils.getMeasurementSystem() === Utils.METRIC_SYSTEM &&
-            distance < SHORT_DISTANCE_THREASHOLD_METRIC) {
-            let prettyDistance =
-                Utils.prettyDistance(SHORT_DISTANCE_THREASHOLD_METRIC);
+        if (Utils.shouldShowImperialUnits() &&
+            distance < SHORT_DISTANCE_THREASHOLD_IMPERIAL) {
+            const prettyDistance =
+                Utils.prettyDistance(SHORT_DISTANCE_THREASHOLD_IMPERIAL);
 
             label = SHORT_DISTANCE_FORMAT.format(prettyDistance);
-        } else if (distance < SHORT_DISTANCE_THREASHOLD_IMPERIAL) {
-            let prettyDistance =
-                Utils.prettyDistance(SHORT_DISTANCE_THREASHOLD_IMPERIAL);
+        } else if (!Utils.shouldShowImperialUnits() &&
+                   distance < SHORT_DISTANCE_THREASHOLD_METRIC) {
+            const prettyDistance =
+                Utils.prettyDistance(SHORT_DISTANCE_THREASHOLD_METRIC);
 
             label = SHORT_DISTANCE_FORMAT.format(prettyDistance);
         } else {
             label = Utils.prettyDistance(distance);
         }
 
-
         this._distanceLabel.label = label;
         this._distanceLabel.visible = true;
     }
