@@ -24,19 +24,6 @@ import GObject from 'gi://GObject';
 import {BoundingBox} from './boundingBox.js';
 import * as Utils from './utils.js';
 
-/* countries/terrotories driving on the left
- * source: https://en.wikipedia.org/wiki/Left-_and_right-hand_traffic
- */
-const LHT_COUNTRIES = new Set(['AG', 'AI', 'AU', 'BB', 'BD', 'BM', 'BN', 'BS',
-                               'BT', 'BW', 'CY', 'DM', 'FJ', 'FK', 'GB', 'GD',
-                               'GY', 'HK', 'ID', 'IE', 'IM', 'IN', 'JE', 'JM',
-                               'JP', 'KE', 'KI', 'KN', 'KY', 'LC', 'LK', 'LS',
-                               'MO', 'MS', 'MT', 'MU', 'MV', 'MW', 'MY', 'MZ',
-                               'NA', 'NP', 'NR', 'NZ', 'PG', 'PN', 'PK', 'SB',
-                               'SC', 'SG', 'SH', 'SR', 'SZ', 'TC', 'TH', 'TL',
-                               'TO', 'TT', 'TV', 'TZ', 'UG', 'VC', 'VG', 'VI',
-                               'WS', 'ZA', 'ZM', 'ZW']);
-
 export class Route extends GObject.Object {
 
     constructor() {
@@ -181,10 +168,7 @@ export class TurnPoint {
     }
 
     _isLefthandTraffic() {
-        let country =
-            Utils.getCountryCodeForCoordinates(this.coordinate.latitude,
-                                               this.coordinate.longitude);
-
-        return LHT_COUNTRIES.has(country);
+        return Utils.isLefthandTrafficForCoordinates(this.coordinate.latitude,
+                                                    this.coordinate.longitude);
     }
 }
