@@ -73,6 +73,8 @@ const WALK_SLACK = 120;
 
 export const DEFAULT_ROUTE_COLOR = '4c4c4c';
 export const DEFAULT_ROUTE_TEXT_COLOR = 'ffffff';
+export const DEFAULT_DARK_ROUTE_COLOR = 'deddda';
+export const DEFAULT_DARK_ROUTE_TEXT_COLOR = '241f31';
 
 export class Plan extends GObject.Object {
 
@@ -324,6 +326,10 @@ export class Itinerary extends GObject.Object {
         if (mins < 60) {
             let minStr = Utils.formatLocaleInteger(mins);
 
+            // don't try to format with a negative number
+            if (mins < 0)
+                return '';
+
             /* translators: this is an indication for a trip duration of
              * less than an hour, with only the minutes part, using plural forms
              * as appropriate
@@ -595,7 +601,7 @@ export class Leg {
     }
 
     get color() {
-        return this._color || DEFAULT_ROUTE_COLOR;
+        return this._color;
     }
 
     set color(color) {
@@ -603,7 +609,7 @@ export class Leg {
     }
 
     get textColor() {
-        return this._textColor || DEFAULT_ROUTE_TEXT_COLOR;
+        return this._textColor;
     }
 
     set textColor(textColor) {
@@ -651,9 +657,13 @@ export class Leg {
             switch (type) {
                 /* special case HVT codes */
                 case HVT.CABLE_CAR:
-                    return 'route-transit-cablecar-symbolic';
+                    return 'cablecar-symbolic';
+                case HVT.HORSE_DRAWN_CARRIAGE:
+                    return 'horse-symbolic';
+                case HVT.MONORAIL:
+                    return 'monorail-symbolic';
                 case HVT.TOURIST_RAILWAY_SERVICE:
-                    return 'route-transit-tourist-train-symbolic';
+                    return 'steam-train-symbolic';
                 default:
                     let hvtSupertype = HVT.supertypeOf(type);
 
@@ -663,48 +673,52 @@ export class Leg {
                     switch (type) {
                         case RouteType.TRAM:
                         case HVT.TRAM_SERVICE:
-                            return 'route-transit-tram-symbolic';
+                            return 'tram-symbolic';
 
                         case RouteType.SUBWAY:
                         case HVT.METRO_SERVICE:
                         case HVT.URBAN_RAILWAY_SERVICE:
                         case HVT.UNDERGROUND_SERVICE:
-                            return 'route-transit-subway-symbolic';
+                            return 'subway-symbolic';
 
                         case RouteType.TRAIN:
                         case HVT.RAILWAY_SERVICE:
                         case HVT.SUBURBAN_RAILWAY_SERVICE:
-                            return 'route-transit-train-symbolic';
+                            return 'train-symbolic';
 
                         case RouteType.BUS:
                         case HVT.BUS_SERVICE:
                         case HVT.COACH_SERVICE:
+                            return 'bus-symbolic';
+
+                        case RouteType.TROLLEYBUS:
                         case HVT.TROLLEYBUS_SERVICE:
-                            /* TODO: handle a special case icon for trolleybus */
-                            return 'route-transit-bus-symbolic';
+                            return 'trolley-bus-symbolic';
 
                         case RouteType.FERRY:
                         case HVT.WATER_TRANSPORT_SERVICE:
                         case HVT.FERRY_SERVICE:
-                            return 'route-transit-ferry-symbolic';
+                            return 'ferry-symbolic';
 
                         case RouteType.CABLE_CAR:
-                            return 'route-transit-cablecar-symbolic';
+                            return 'cablecar-symbolic';
 
                         case RouteType.GONDOLA:
                         case HVT.TELECABIN_SERVICE:
-                            return 'route-transit-gondolalift-symbolic';
+                            return 'gondola-symbolic';
 
                         case RouteType.FUNICULAR:
                         case HVT.FUNICULAR_SERVICE:
-                            return 'route-transit-funicular-symbolic';
+                            return 'funicular-symbolic';
 
                         case HVT.TAXI_SERVICE:
-                            /* TODO: should we have a dedicated taxi icon? */
-                            return 'route-car-symbolic';
+                            return 'taxi-symbolic';
 
                         case HVT.AIR_SERVICE:
-                            return 'route-transit-airplane-symbolic';
+                            return 'flying-symbolic';
+
+                        case RouteType.MONORAIL:
+                            return 'monorail-symbolic';
 
                         default:
                             /* use a fallback question mark icon in case of some future,
@@ -713,7 +727,7 @@ export class Leg {
                     }
             }
         } else {
-            return 'route-pedestrian-symbolic';
+            return 'walking-symbolic';
         }
     }
 
@@ -783,6 +797,18 @@ export class Stop {
         return this._coordinate;
     }
 
+    get arrival() {
+        return this._arrival;
+    }
+
+    get departure() {
+        return this._departure;
+    }
+
+    get agencyTimezoneOffset() {
+        return this._agencyTimezoneOffset;
+    }
+
     prettyPrint(params) {
         if (params.isFinal) {
             /* take the stop arrival time and offset using the timezone
