@@ -30,12 +30,11 @@ import Gtk from 'gi://Gtk';
 import Adw from 'gi://Adw';
 import GWeather from 'gi://GWeather';
 
+import {Settings} from './settings.js';
+
 const _ = gettext.gettext;
 const ngettext = gettext.ngettext;
 
-export const METRIC_SYSTEM = 1;
-export const IMPERIAL_SYSTEM = 2;
-
 //List of locales using imperial system according to glibc locale database
 const IMPERIAL_LOCALES = ['unm_US', 'es_US', 'es_PR', 'en_US', 'yi_US'];
 
@@ -50,13 +49,20 @@ const _integerTwoDigitFormat =
     new Intl.NumberFormat([], { minimumIntegerDigits: 2,
                                 maximumFractionDigits: 0 });
 
-let debugInit = false;
-let measurementSystem = null;
+/* countries/terrotories driving on the left
+ * source: https://en.wikipedia.org/wiki/Left-_and_right-hand_traffic
+ */
+const LHT_COUNTRIES = new Set(['AG', 'AI', 'AU', 'BB', 'BD', 'BM', 'BN', 'BS',
+                               'BT', 'BW', 'CY', 'DM', 'FJ', 'FK', 'GB', 'GD',
+                               'GY', 'HK', 'ID', 'IE', 'IM', 'IN', 'JE', 'JM',
+                               'JP', 'KE', 'KI', 'KN', 'KY', 'LC', 'LK', 'LS',
+                               'MO', 'MS', 'MT', 'MU', 'MV', 'MW', 'MY', 'MZ',
+                               'NA', 'NP', 'NR', 'NZ', 'PG', 'PN', 'PK', 'SB',
+                               'SC', 'SG', 'SH', 'SR', 'SZ', 'TC', 'TH', 'TL',
+                               'TO', 'TT', 'TV', 'TZ', 'UG', 'VC', 'VG', 'VI',
+                               'WS', 'ZA', 'ZM', 'ZW']);
 
-// this should only be used by the unit test to hard-set the measurement system
-export function _setMeasurementSystem(m) {
-    measurementSystem = m;
-}
+let debugInit = false;
 
 export var debugEnabled = false;
 
@@ -214,22 +220,37 @@ export function writeFile(filename, buffer) {
     }
 }
 
-export function getMeasurementSystem() {
-    if (measurementSystem)
-        return measurementSystem;
+// only to be used by tests
+var _overrideMeasurementSystem;
 
-    let locale = GLib.getenv('LC_MEASUREMENT') || GLib.get_language_names()[0];
+export function _setOverrideMeasurementSystem(measurementSystem) {
+    _overrideMeasurementSystem = measurementSystem;
+}
 
-    // Strip charset
-    if (locale.indexOf('.') !== -1)
-        locale = locale.substring(0, locale.indexOf('.'));
+export function shouldShowImperialUnits() {
+    const measurementSystemSetting =
+        _overrideMeasurementSystem ??
+        Settings.getSettings('org.gnome.Maps').get('measurement-system');
 
-    if (IMPERIAL_LOCALES.indexOf(locale) === -1)
-        measurementSystem = METRIC_SYSTEM;
-    else
-        measurementSystem = IMPERIAL_SYSTEM;
+    switch (measurementSystemSetting) {
+        case 'system':
+            let locale = GLib.getenv('LC_MEASUREMENT') || GLib.get_language_names()[0];
 
-    return measurementSystem;
+            // Strip charset
+            if (locale.indexOf('.') !== -1)
+                locale = locale.substring(0, locale.indexOf('.'));
+
+            if (IMPERIAL_LOCALES.indexOf(locale) === -1)
+                return false;
+            else
+                return true;
+        case 'metric':
+            return false;
+        case 'imperial':
+            return true;
+        default:
+            return false;
+    }
 }
 
 /**
@@ -328,17 +349,7 @@ export function prettyTime(time) {
 }
 
 export function prettyDistance(distance, noRound) {
-    if (getMeasurementSystem() === METRIC_SYSTEM) {
-        // round to whole meters
-        distance = Math.round(distance);
-        if (distance >= 1000 && !noRound) {
-            distance = Math.round(distance / 1000 * 10) / 10;
-            /* Translators: This is a distance measured in kilometers */
-            return _("%s km").format(distance.toLocaleString());
-        } else
-            /* Translators: This is a distance measured in meters */
-            return _("%s m").format(distance.toLocaleString());
-    } else {
+    if (shouldShowImperialUnits()) {
         // Convert to feet
         distance = Math.round(distance * 3.2808399);
         if (distance >= 1056 && !noRound) {
@@ -346,9 +357,21 @@ export function prettyDistance(distance, noRound) {
             distance = Math.round(distance / 5280 * 10) / 10;
             /* Translators: This is a distance measured in miles */
             return _("%s mi").format(distance.toLocaleString());
-        } else
+        } else {
             /* Translators: This is a distance measured in feet */
             return _("%s ft").format(distance.toLocaleString());
+        }
+    } else {
+        // round to whole meters
+        distance = Math.round(distance);
+        if (distance >= 1000 && !noRound) {
+            distance = Math.round(distance / 1000 * 10) / 10;
+            /* Translators: This is a distance measured in kilometers */
+            return _("%s km").format(distance.toLocaleString());
+        } else {
+            /* Translators: This is a distance measured in meters */
+            return _("%s m").format(distance.toLocaleString());
+        }
     }
 }
 
@@ -450,3 +473,26 @@ export function splitAtFirst(string, separator) {
         return [first];
     }
 }
+
+/**
+ * Determines if left-hand road traffic is used in a given location.
+ *
+ * @param {number} latitude
+ * @param {number} longitude
+ * @return {boolean} true if the given location has LHT
+ */
+export function isLefthandTrafficForCoordinates(latitude, longitude) {
+    const country = getCountryCodeForCoordinates(latitude, longitude);
+
+    return isLefthandTrafficForCountry(country);
+}
+
+/**
+ * Determine if left-hand road traffic is used in a given country/region.
+ *
+ * @param {string} ISO country code
+ * @return {boolean} true if the given location has LHT
+ */
+export function isLefthandTrafficForCountry(country) {
+    return LHT_COUNTRIES.has(country);
+}
